==> smartclientcore7.5.6.zip: docs/constants/interfaces/interfaces/NonLinearVariation.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / NonLinearVariation

# Interface: NonLinearVariation

## Extends

- [`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md)

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`adParameters`](constants/interfaces/interfaces/BaseCreative.md#adparameters)

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`apiFramework`](constants/interfaces/interfaces/BaseCreative.md#apiframework)

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickThroughURL`](constants/interfaces/interfaces/BaseCreative.md#clickthroughurl)

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: `object`[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickTracker`](constants/interfaces/interfaces/BaseCreative.md#clicktracker)

***

<a id="creativetrackers" name="creativetrackers"></a>

### creativeTrackers

> **creativeTrackers**: `Record`\<`string`, `object`[]\>

***

<a id="displayduration" name="displayduration"></a>

### displayDuration

> **displayDuration**: `null` \| `number`

***

<a id="expandedheight" name="expandedheight"></a>

### expandedHeight

> **expandedHeight**: `number`

***

<a id="expandedwidth" name="expandedwidth"></a>

### expandedWidth

> **expandedWidth**: `number`

***

<a id="height" name="height"></a>

### height

> **height**: `number`

***

<a id="id" name="id"></a>

### id

> **id**: `null` \| `string`

***

<a id="maintainaspectratio" name="maintainaspectratio"></a>

### maintainAspectRatio

> **maintainAspectRatio**: `boolean`

***

<a id="minsuggestedduration" name="minsuggestedduration"></a>

### minSuggestedDuration

> **minSuggestedDuration**: `number`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`resources`](constants/interfaces/interfaces/BaseCreative.md#resources)

***

<a id="scalable" name="scalable"></a>

### scalable

> **scalable**: `boolean`

***

<a id="selectedresource" name="selectedresource"></a>

### selectedResource

> **selectedResource**: [`Resource`](constants/interfaces/interfaces/Resource.md)

***

<a id="width" name="width"></a>

### width

> **width**: `number`

==> smartclientcore7.6.2.zip: docs/constants/interfaces/interfaces/NonLinearVariation.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / NonLinearVariation

# Interface: NonLinearVariation

## Extends

- [`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md)

## Properties

<a id="adparameters" name="adparameters"></a>

### adParameters

> **adParameters**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`adParameters`](constants/interfaces/interfaces/BaseCreative.md#adparameters)

***

<a id="apiframework" name="apiframework"></a>

### apiFramework

> **apiFramework**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`apiFramework`](constants/interfaces/interfaces/BaseCreative.md#apiframework)

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `null` \| `string`

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickThroughURL`](constants/interfaces/interfaces/BaseCreative.md#clickthroughurl)

***

<a id="clicktracker" name="clicktracker"></a>

### clickTracker

> **clickTracker**: [`ClickTracker`](constants/interfaces/interfaces/ClickTracker.md)[] \| [`CreativeViewTracker`](constants/interfaces/interfaces/CreativeViewTracker.md)[] \| [`Tracker`](constants/interfaces/interfaces/Tracker.md)[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`clickTracker`](constants/interfaces/interfaces/BaseCreative.md#clicktracker)

***

<a id="creativetrackers" name="creativetrackers"></a>

### creativeTrackers

> **creativeTrackers**: [`TrackingEvents`](constants/interfaces/interfaces/TrackingEvents.md)

***

<a id="displayduration" name="displayduration"></a>

### displayDuration

> **displayDuration**: `null` \| `number`

***

<a id="expandedheight" name="expandedheight"></a>

### expandedHeight

> **expandedHeight**: `number`

***

<a id="expandedwidth" name="expandedwidth"></a>

### expandedWidth

> **expandedWidth**: `number`

***

<a id="height" name="height"></a>

### height

> **height**: `number`

***

<a id="id" name="id"></a>

### id

> **id**: `null` \| `string`

***

<a id="maintainaspectratio" name="maintainaspectratio"></a>

### maintainAspectRatio

> **maintainAspectRatio**: `boolean`

***

<a id="minsuggestedduration" name="minsuggestedduration"></a>

### minSuggestedDuration

> **minSuggestedDuration**: `number`

***

<a id="resources" name="resources"></a>

### resources

> **resources**: [`Resource`](constants/interfaces/interfaces/Resource.md)[]

#### Inherited from

[`BaseCreative`](constants/interfaces/interfaces/BaseCreative.md).[`resources`](constants/interfaces/interfaces/BaseCreative.md#resources)

***

<a id="scalable" name="scalable"></a>

### scalable

> **scalable**: `boolean`

***

<a id="selectedresource" name="selectedresource"></a>

### selectedResource

> **selectedResource**: [`Resource`](constants/interfaces/interfaces/Resource.md)

***

<a id="width" name="width"></a>

### width

> **width**: `number`
